Welcome to Fabex
================

Fabex is a set of extensions to Python Fabric that extend the roles
feature and manages deploy target configurations, templates and build
steps. Fabex adds tasks, decorators, and context managers to "make
roles work better."

Documentation at http://fabex.readthedocs.org/en/latest/
